==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CategoryItemHighlightLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryItemHighlightLayerDescription } from "./CategoryItemHighlightLayerDescription";
/**
 * @hidden
 */
var CategoryItemHighlightLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryItemHighlightLayerDescriptionMetadata, _super);
    function CategoryItemHighlightLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryItemHighlightLayerDescriptionMetadata.b = function (a) {
        if (CategoryItemHighlightLayerDescriptionMetadata.a == null) {
            CategoryItemHighlightLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryItemHighlightLayerDescriptionMetadata.c(CategoryItemHighlightLayerDescriptionMetadata.a);
        }
        if (a.g(CategoryItemHighlightLayerDescriptionMetadata.a)) {
            return;
        }
        a.s(CategoryItemHighlightLayerDescriptionMetadata.a);
    };
    CategoryItemHighlightLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
        a.item("TargetSeriesName", "String");
        a.item("UseInterpolation", "Boolean");
        a.item("HighlightType", "ExportedType:string:CategoryItemHighlightType");
        a.item("HighlightType@names", "Auto;Marker;Shape");
        a.item("MarkerType", "ExportedType:string:MarkerType");
        a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
        a.item("MarkerBrush", "Brush");
        a.item("MarkerOutline", "Brush");
        a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
        a.item("BandHighlightWidth", "Number:double");
        a.item("SkipUnknownValues", "Boolean");
    };
    CategoryItemHighlightLayerDescriptionMetadata.d = function (a) {
        CategoryItemHighlightLayerDescriptionMetadata.b(a);
        a.u("CategoryItemHighlightLayer", function () { return new CategoryItemHighlightLayerDescription(); });
        a.t("CategoryItemHighlightLayer", CategoryItemHighlightLayerDescriptionMetadata.a);
    };
    CategoryItemHighlightLayerDescriptionMetadata.$t = markType(CategoryItemHighlightLayerDescriptionMetadata, 'CategoryItemHighlightLayerDescriptionMetadata');
    CategoryItemHighlightLayerDescriptionMetadata.a = null;
    return CategoryItemHighlightLayerDescriptionMetadata;
}(Base));
export { CategoryItemHighlightLayerDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CategoryItemHighlightLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryItemHighlightLayerDescription } from "./CategoryItemHighlightLayerDescription";
/**
 * @hidden
 */
var CategoryItemHighlightLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryItemHighlightLayerDescriptionMetadata, _super);
    function CategoryItemHighlightLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryItemHighlightLayerDescriptionMetadata.b = function (a) {
        if (CategoryItemHighlightLayerDescriptionMetadata.a == null) {
            CategoryItemHighlightLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryItemHighlightLayerDescriptionMetadata.c(CategoryItemHighlightLayerDescriptionMetadata.a);
        }
        if (a.j(CategoryItemHighlightLayerDescriptionMetadata.a)) {
            return;
        }
        a.y(CategoryItemHighlightLayerDescriptionMetadata.a);
    };
    CategoryItemHighlightLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
        a.item("TargetSeriesName", "String");
        a.item("UseInterpolation", "Boolean");
        a.item("HighlightType", "ExportedType:string:CategoryItemHighlightType");
        a.item("HighlightType@names", "Auto;Marker;Shape");
        a.item("MarkerType", "ExportedType:string:MarkerType");
        a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
        a.item("MarkerBrush", "Brush");
        a.item("MarkerOutline", "Brush");
        a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
        a.item("BandHighlightWidth", "Number:double");
        a.item("SkipUnknownValues", "Boolean");
    };
    CategoryItemHighlightLayerDescriptionMetadata.d = function (a) {
        CategoryItemHighlightLayerDescriptionMetadata.b(a);
        a.aa("CategoryItemHighlightLayer", function () { return new CategoryItemHighlightLayerDescription(); });
        a.z("CategoryItemHighlightLayer", CategoryItemHighlightLayerDescriptionMetadata.a);
    };
    CategoryItemHighlightLayerDescriptionMetadata.$t = markType(CategoryItemHighlightLayerDescriptionMetadata, 'CategoryItemHighlightLayerDescriptionMetadata');
    CategoryItemHighlightLayerDescriptionMetadata.a = null;
    return CategoryItemHighlightLayerDescriptionMetadata;
}(Base));
export { CategoryItemHighlightLayerDescriptionMetadata };
